:notoc:

.. _user-guide:

===========
Coiled Docs
===========

👋 Welcome to Coiled's documentation! This guide covers the core concepts and functionality of Coiled.

Coiled helps scale Python by managing three things:

1) **Software environments**: Build, manage, and share conda, pip, and Docker environments.
   Use them locally or in the cloud.
2) **Hosted Dask clusters**: Securely deploy Dask clusters from anywhere you run Python.
3) **Users and costs**: Manage teams, collaborate, set resource limits, and track costs.


.. toctree::
   :maxdepth: 1
   :hidden:

   getting_started
   software_environment
   cluster
   teams
   api
   configuration
   jupyter
   security
   faq
   changelog
   feedback


Feedback
--------

Feedback on Coiled is always welcome and encouraged. If you have any
comments, questions, or other feedback, please
`open an issue <https://github.com/coiled/coiled-issues/issues/new>`_ in the
Coiled issue tracker on GitHub.

.. link-button:: https://github.com/coiled/coiled-issues/issues/new
    :type: url
    :text: Report an issue
    :classes: btn-outline-primary btn-block


Thank you for trying out Coiled!
